@@ -2,13 +2,13 @@
 #' 
 #' Various plots for Markov models probabilistic analysis.
 #' 
-#' \code{type = "ac"} plots cost-effectiveness acceptability
-#' curves, \code{type = "ce"} plots results on the 
-#' cost-efficiency plane, \code{type = "cov"} to perform 
-#' covariance analysis on the results, \code{type = "evpi"} 
+#' `type = "ac"` plots cost-effectiveness acceptability
+#' curves, `type = "ce"` plots results on the 
+#' cost-efficiency plane, `type = "cov"` to perform 
+#' covariance analysis on the results, `type = "evpi"` 
 #' for expected value of perfect information.
 #' 
-#' @param x Result from \code{\link{run_model}}.
+#' @param x Result from [run_model()].
 #' @param type Type of plot, see details.
 #' @param max_wtp Maximal willingness to pay.
 #' @param n Number of CECA points to estimate (values above 
@@ -16,12 +16,12 @@
 #' @param log_scale Show willingness to pay on a log scale?
 #' @param diff Logical, perform covariance analysis on
 #'   strategy differences?
-#' @param threshold When \code{diff = TRUE}, threshlod value
+#' @param threshold When `diff = TRUE`, threshlod value
 #'   for net monetary benefit computation.
 #' @param bw Black & white plot for publications?
-#' @param ... Additional arguments, depends on \code{type}.
+#' @param ... Additional arguments, depends on `type`.
 #'   
-#' @return A \code{ggplot2} object.
+#' @return A `ggplot2` object.
 #' @export
 #' 
 plot.psa <- function(x, type = c("ce", "ac", "cov", "evpi"),
@@ -133,8 +133,8 @@ scale.psa <- function(x, center = TRUE, scale = TRUE) {
   if (scale) {
     res <- res %>% 
       dplyr::mutate_(
-        .cost = ~ .cost / sum(get_init(get_model(x))),
-        .effect = ~ .effect / sum(get_init(get_model(x)))
+        .cost = ~ .cost / .n_indiv,
+        .effect = ~ .effect / .n_indiv
       )
   }
   
