@@ -2,9 +2,8 @@
 #' 
 #' @param model An evaluated Markov model.
 #' @param dsa An object returned by 
-#'   \code{\link{define_dsa}}.
-#'   
-#' @return A \code{data.frame} with one row per model and 
+#'   [define_dsa()].
+#' @return A `data.frame` with one row per model and 
 #'   parameter value.
 #' @export
 #' 
@@ -15,12 +14,17 @@ run_dsa <- function(model, dsa) {
     stop("No cost and/or effect defined, sensitivity analysis unavailable.")
   }
   
-  init <- get_init(model)
+  init <- get_uneval_init(model)
   cycles <- get_cycles(model)
   method <- get_method(model)
   strategy_names <- get_strategy_names(model)
   
+  n_par <- length(dsa$variables)
+  pos_par <- cumsum(c(1, rep(c(n_par, n_par+1), n_par)))
+  pos_par <- pos_par[-length(pos_par)]
+  
   list_res <- list()
+  e_newdata <- list()
   for (n in strategy_names) {
     message(sprintf(
       "Running DSA on strategy '%s'...", n
@@ -29,17 +33,27 @@ run_dsa <- function(model, dsa) {
       model,
       strategy = n,
       newdata = dsa$dsa
-    ) 
+    )
+    
     res <- tab %>% 
       dplyr::mutate_if(
         names(tab) %in% dsa$variables,
         dplyr::funs(to_text_dots),
         name = FALSE
       )
+    
     list_res <- c(
       list_res,
       list(res)
     )
+    
+    e_newdata <- c(
+      e_newdata,
+      list(unlist(lapply(
+        tab$.mod,
+        function(x) x$parameters[1, dsa$variables]))[pos_par]))
+    
+    names(e_newdata)[length(e_newdata)] <- n
   }
   
   for (i in seq_along(strategy_names)) {
@@ -47,14 +61,19 @@ run_dsa <- function(model, dsa) {
   }
   
   res <- Reduce(dplyr::bind_rows, list_res) %>% 
-    tidyr::gather_(".par_names", ".par_value",
-                   dsa$variables, na.rm = TRUE)
+    tidyr::gather_(
+      ".par_names", ".par_value",
+      dsa$variables, na.rm = TRUE) %>% 
+    dplyr::rowwise()
+  
   res <- res %>% 
-    dplyr::rowwise() %>% 
     dplyr::do_(~ get_total_state_values(.$.mod)) %>% 
     dplyr::bind_cols(res %>% dplyr::select_(~ - .mod)) %>% 
     dplyr::ungroup() %>% 
-    dplyr::mutate_(.dots = get_ce(model))
+    dplyr::mutate(
+      .par_value_eval = unlist(e_newdata)) %>% 
+    dplyr::mutate_(
+      .dots = get_ce(model))
   
   structure(
     list(
@@ -62,10 +81,23 @@ run_dsa <- function(model, dsa) {
       variables = dsa$variables,
       model = model
     ),
-    class = c("dsa", class(res))
+    class = c("dsa", "list")
   )
 }
 
 get_model.dsa <- function(x) {
   x$model
-}
\ No newline at end of file
+}
+
+digits_at_diff <- function(x, y, addl_digits = 1){
+  stopifnot(length(x) == length(y))
+  diff <- abs(x - y)
+  num_digits <- -floor(log(diff, 10)) + addl_digits
+  round_x <- 
+    sapply(seq(along = x), 
+           function(i){round(x[i], num_digits[i])})
+  round_y <- 
+    sapply(seq(along = y), 
+           function(i){round(y[i], num_digits[i])})
+  list(x = round_x, y = round_y, nd = num_digits)
+}
