@@ -3,25 +3,37 @@
 #' Plot the results of a sensitivity analysis as a tornado 
 #' plot.
 #' 
-#' Plot type \code{simple} plots variations of single strategy 
-#' values, while \code{difference} plots incremental values.
+#' Plot type `simple` plots variations of single strategy 
+#' values, while `difference` plots incremental values.
 #' 
-#' @param x A result of \code{\link{run_dsa}}.
+#' @param x A result of [run_dsa()].
 #' @param strategy Name or index of strategies to plot.
 #' @param type Type of plot (see details).
 #' @param result Plot cost, effect, or ICER.
-#' @param widest_on_top logical. Should bars be sorted so
+#' @param widest_on_top logical. Should bars be sorted so 
 #'   widest are on top?
+#' @param limits_by_bars logical. Should the limits used
+#'   for each parameter be printed in the plot, next to the
+#'   bars?
+#' @param resolve_labels logical. Should we resolve all
+#'   labels to numbers instead of expressions (if there are
+#'   any)?
+#' @param shorten_labels logical. Should we shorten the
+#'   presentation of the parameters on the plot to highlight
+#'   where the values differ?
 #' @param bw Black & white plot for publications?
 #' @param remove_ns Remove variables that are not sensitive.
-#' @param ... Additional arguments passed to \code{plot}.
+#' @param ... Additional arguments passed to `plot`.
 #'   
-#' @return A \code{ggplot2} object.
+#' @return A `ggplot2` object.
 #' @export
 #' 
 plot.dsa <- function(x, type = c("simple", "difference"),
                      result = c("cost", "effect", "icer"),
                      strategy = NULL, widest_on_top = TRUE,
+                     limits_by_bars = TRUE,
+                     resolve_labels = FALSE,
+                     shorten_labels = FALSE,
                      remove_ns = FALSE,
                      bw = FALSE, ...) {
   
@@ -83,6 +95,13 @@ plot.dsa <- function(x, type = c("simple", "difference"),
     }
   )
   
+  if (resolve_labels) {
+    x$dsa <- x$dsa %>%
+      dplyr::mutate_(
+        .par_value = ~ .par_value_eval
+      )
+  }
+  
   tab <- summary(x, center = FALSE)$res_comp %>% 
     dplyr::left_join(
       summary(model_ref, center = FALSE)$res_comp %>%
@@ -136,6 +155,22 @@ plot.dsa <- function(x, type = c("simple", "difference"),
   
   l <- diff(range(tab[[var_plot]])) * .1
   
+  if (type == "difference") {
+    tab$.strategy_names <- "difference"
+  }
+  
+  if (shorten_labels) {
+    odds <- seq(from = 1, to = nrow(tab), by = 2)
+    evens <- odds + 1
+    new_digits <- digits_at_diff(as.numeric(tab$.par_value[odds]), 
+                                 as.numeric(tab$.par_value[evens]),
+                                 addl_digits = 2)
+    tab$.par_value[odds] <- new_digits$x
+    tab$.par_value[evens] <- new_digits$y
+    
+    if (limits_by_bars) l <- l * (1 + 0.075 * max(new_digits$nd))
+  }
+  
   res <- ggplot2::ggplot(tab, ggplot2::aes_string(
     y = ".par_names",
     yend = ".par_names",
@@ -147,16 +182,20 @@ plot.dsa <- function(x, type = c("simple", "difference"),
     ggplot2::ylab("Variable") +
     ggplot2::xlab(xl) +
     ggplot2::xlim(min(tab[[var_plot]]) - l, max(tab[[var_plot]]) + l) +
-    ggplot2::geom_text(
-      ggplot2::aes_string(
-        x = var_plot,
-        y = ".par_names",
-        label = ".par_value",
-        hjust = ".hjust"
-      )
-    ) +
     ggplot2::facet_wrap(stats::as.formula("~ .strategy_names"))
   
+  if (limits_by_bars) {
+    res <- res + 
+      ggplot2::geom_text(
+        ggplot2::aes_string(
+          x = var_plot,
+          y = ".par_names",
+          label = ".par_value",
+          hjust = ".hjust"
+        )
+      )
+  }
+  
   if (bw) {
     res <- res +
       ggplot2::scale_color_grey(start = 0, end = .8) +
@@ -210,8 +249,8 @@ scale.dsa <- function(x, center = TRUE, scale = TRUE) {
   if (scale) {
     res <- res %>% 
       dplyr::mutate_(
-        .cost = ~ .cost / sum(get_init(get_model(x))),
-        .effect = ~ .effect / sum(get_init(get_model(x)))
+        .cost = ~ .cost / .n_indiv,
+        .effect = ~ .effect / .n_indiv
       )
   }
   
@@ -251,3 +290,16 @@ tidy_dsa <- function(x) {
   tab %>% 
     tidyr::gather()
 }
+
+digits_at_diff <- function(x, y, addl_digits = 1){
+  stopifnot(length(x) == length(y))
+  diff <- abs(x - y)
+  num_digits <- -floor(log(diff, 10)) + addl_digits
+  round_x <- 
+    sapply(seq(along = x), 
+           function(i){round(x[i], num_digits[i])})
+  round_y <- 
+    sapply(seq(along = y), 
+           function(i){round(y[i], num_digits[i])})
+  list(x = round_x, y = round_y, nd = num_digits)
+}
