@@ -2,16 +2,16 @@
 #' 
 #' This function runs a model from tabular input.
 #' 
-#' The reference file should have two columns, \code{data} 
-#' and \code{file}. An optional \code{absolute_path} column 
-#' can be added, having value \code{TRUE} where an absolute 
-#' file path is provided. \code{data} values must include 
-#' \code{state}, \code{tm}, and \code{parameters}, and can 
-#' also include \code{options}, \code{demographics} and 
-#' \code{data}.  The corresponding values in the \code{file}
+#' The reference file should have two columns, `data` 
+#' and `file`. An optional `absolute_path` column 
+#' can be added, having value `TRUE` where an absolute 
+#' file path is provided. `data` values must include 
+#' `state`, `tm`, and `parameters`, and can 
+#' also include `options`, `demographics` and 
+#' `data`.  The corresponding values in the `file`
 #' column give the names of the files (located in 
-#' \code{base_dir}) that contain the corresponding 
-#' information - or, in the case of \code{data}, the 
+#' `base_dir`) that contain the corresponding 
+#' information - or, in the case of `data`, the 
 #' directory containing the tables to be loaded.
 #' 
 #' @param location Directory where the files are located.
@@ -52,8 +52,8 @@ run_model_tabular <- function(location, reference = "REFERENCE.csv",
 #' @param ref_file Name of the reference file.
 #'   
 #' @return A list with elements: \itemize{ \item models (of 
-#'   type \code{uneval_model}, created by 
-#'   \code{\link{create_model_list_from_tabular}}) \item 
+#'   type `uneval_model`, created by 
+#'   [create_model_list_from_tabular()]) \item 
 #'   param_info  \item output_dir where to store output 
 #'   files, if specified \item demographic_file a table for 
 #'   demographic analysis \item model_options a list of 
@@ -113,6 +113,23 @@ gather_model_info <- function(base_dir, ref_file) {
     )
   }
   
+  if ("source" %in% ref$data) {
+    if(options()$heemod.verbose) message("** Reading R source files...")
+    source_dir <- ref$full_file[ref$data == "source"]
+    short_source_dir <- ref$file[ref$data == "source"]
+    if (! dir.exists(source_dir)) {
+      stop("'source' directory missing: ", short_source_dir)
+    }
+    source_list <- list.files(source_dir, full.names = TRUE)
+    if (length(source_list) == 0) {
+      stop("No source files in 'source' directory: ", 
+           short_source_dir)                      
+    }                                    
+    for (this_file in source_list) { 
+      source(this_file, echo = FALSE, local = df_env)
+    }
+  }
+  
   ## note - the environment df_env gets included directly
   ##   into param_info, so anything that will load anything
   ##   into that environment needs to come before this statement
@@ -154,17 +171,17 @@ gather_model_info <- function(base_dir, ref_file) {
 #' analysis, and analyses across demographics.
 #' 
 #' @param inputs Result from 
-#'   \code{\link{gather_model_info}}.
+#'   [gather_model_info()].
 #' @param run_psa Run PSA?
 #' @param run_demo Run demographic analysis?
 #'   
-#' @return a list \itemize{ \item \code{models} (always) 
-#'   unevaluated model. \item \code{model_runs} (always) 
-#'   evaluated models \item \code{dsa} (deterministic 
+#' @return a list \itemize{ \item `models` (always) 
+#'   unevaluated model. \item `model_runs` (always) 
+#'   evaluated models \item `dsa` (deterministic 
 #'   sensitivity analysis) - if appropriate parameters 
-#'   provided \item \code{psa} (probabilistic sensitivity 
+#'   provided \item `psa` (probabilistic sensitivity 
 #'   analysis) - if appropriate parameters provided \item 
-#'   \code{demographics} results across different 
+#'   `demographics` results across different 
 #'   demographic groups - if appropriate parameters 
 #'   provided}
 #'   
@@ -261,15 +278,36 @@ create_model_list_from_tabular <- function(ref, df_env = globalenv()) {
     read_file(ref$full_file[ref$data == "state"]),
     group_vars = ".state"
   )
-  
+  state_names <- state_info[[1]]$.state
   ## to accomodate partitioned survival models, we will allow for
   ##   the possibility that there is no transition matrix ...
   if (options()$heemod.verbose) message("*** Reading TM...")
   
-  tm_info <- parse_multi_spec(
-    read_file(ref$full_file[ref$data == "tm"]),
-    group_vars = c("from", "to")
-  )
+  tm_info <- read_file(ref$full_file[ref$data == "tm"])
+  trans_type <- transition_type(tm_info)
+  
+  if (trans_type == "matrix") {
+    tm_info <- parse_multi_spec(
+      tm_info,
+      group_vars = c("from", "to"))
+    tab_undefined <- do.call("rbind", tm_info) %>% 
+      dplyr::filter_(~ is.na(prob))
+    
+    if (nrow(tab_undefined) > 0) {
+      rownames(tab_undefined) <- NULL
+      print(tab_undefined)
+      stop("Undefined probabilities in the transition matrix (see above).")
+    }
+  } else if (trans_type == "part_surv") {
+    # fit_matrix <- partitioned_survival_from_ref_struc(
+    #   ref, df_env,
+    #   state_names,
+    #   save_fits = FALSE,
+    #   just_load = TRUE)
+    # use_fits_text <- ref[ref$data == "use_fits", "file"]
+    # use_fits <- eval(parse(text = use_fits_text))
+    # tm_info <- combine_part_surv_(fit_matrix, use_fits)
+  }
   
   if (length(pb <- setdiff(names(state_info), names(tm_info)))) {
     stop(sprintf(
@@ -280,17 +318,9 @@ create_model_list_from_tabular <- function(ref, df_env = globalenv()) {
   
   tm_info <- tm_info[names(state_info)]
   
-  tab_undefined <- do.call("rbind", tm_info) %>% 
-    dplyr::filter_(~ is.na(prob))
-  
-  if (nrow(tab_undefined) > 0) {
-    rownames(tab_undefined) <- NULL
-    print(tab_undefined)
-    stop("Undefined probabilities in the transition matrix (see above).")
-  }
   
   
-if (options()$heemod.verbose) message("*** Defining models...")
+  if (options()$heemod.verbose) message("*** Defining models...")
   models <- lapply(
     seq_along(state_info),
     function(i) {
@@ -306,7 +336,7 @@ if (options()$heemod.verbose) message("*** Defining models...")
 #' Create State Definitions From Tabular Input
 #' 
 #' Transforms tabular input defining states into an 
-#' \code{heemod} object.
+#' `heemod` object.
 #' 
 #' Columns of state_info besides .model and state include 
 #' costs and utilities we want to keep track of, with 
@@ -326,10 +356,10 @@ if (options()$heemod.verbose) message("*** Defining models...")
 #' The input data frame is expected to contain state 
 #' information for all the models you will use in an 
 #' analysis. For more information see the vignette: 
-#' \code{vignette("file-input", package = "heemod")}.
+#' `vignette("file-input", package = "heemod")`.
 #' 
 #' @param state_info Result for one model of 
-#'   \code{\link{parse_multi_spec}}.
+#'   [parse_multi_spec()].
 #' @param df_env An environment containing external data.
 #'   
 #' @return A state list.
@@ -414,24 +444,24 @@ create_states_from_tabular <- function(state_info,
 #' Create a Transition Matrix From Tabular Input
 #' 
 #' Transforms tabular input defining a transition matrix 
-#' into an \code{heemod} object.
+#' into an `heemod` object.
 #' 
-#' The data frame \code{trans_probs} should have columns 
-#' \code{from}, \code{to}, and \code{prob}, where 
-#' \code{prob} is the probability of a transition from the 
-#' \code{from} state to the \code{to} state. Prob can be 
+#' The data frame `trans_probs` should have columns 
+#' `from`, `to`, and `prob`, where 
+#' `prob` is the probability of a transition from the 
+#' `from` state to the `to` state. Prob can be 
 #' defined in terms of parameters, just as when using 
-#' \code{define_transition} at the keyboard. Probabilities of 0 
+#' `define_transition` at the keyboard. Probabilities of 0 
 #' need not be specified - they will be automatically 
 #' inserted.
 #' 
-#' All state names must be used in the \code{from} column of
+#' All state names must be used in the `from` column of
 #' the transition matrix (otherwise you can just get rid of 
 #' the state). Absorbing states should have a transition 
 #' from and to themselves with probability 1.
 #' 
 #' @param trans_probs  Result for one model of 
-#'   \code{\link{parse_multi_spec}}.
+#'   [parse_multi_spec()].
 #' @param state_names The names of the states used in the 
 #'   transition matrix.
 #' @param df_env An environment containing external data.
@@ -493,10 +523,10 @@ create_matrix_from_tabular <- function(trans_probs, state_names,
 #' created.
 #' 
 #' The tabular parameter definition file can have the 
-#' following columns: \code{parameter} (the parameter name, 
-#' required), \code{value} (required), \code{low} and 
-#' \code{high} (if both are present, a deterministic 
-#' sensitivity analysis will be performed), and \code{psa} 
+#' following columns: `parameter` (the parameter name, 
+#' required), `value` (required), `low` and 
+#' `high` (if both are present, a deterministic 
+#' sensitivity analysis will be performed), and `psa` 
 #' (a definition of a distribution to use in a probabilistic
 #' sensitivity analysis. Other columns will be ignored.
 #' 
@@ -590,6 +620,22 @@ create_parameters_from_tabular <- function(param_defs,
     
   }
   
+  ## if there are multinomials specified, 
+  ##  fix them up in the parameters and redefine
+  param_defs_new <- 
+    modify_param_defs_for_multinomials(param_defs, psa)
+  
+  parameters <- define_parameters_(
+    lazyeval::as.lazy_dots(
+      stats::setNames(
+        as.character(lapply(param_defs_new$value, function(x) x)),
+        param_defs_new$parameter
+      ),
+      env = df_env
+    )
+  )
+  
+  
   list(
     params = parameters,
     dsa_params = dsa,
@@ -660,10 +706,10 @@ create_options_from_tabular <- function(opt) {
   res
 }
 
-#' Create a \code{heemod} Model From Tabular Files Info
+#' Create a `heemod` Model From Tabular Files Info
 #' 
-#' Calls \code{\link{create_states_from_tabular}} and
-#' \code{\link{create_matrix_from_tabular}}.
+#' Calls [create_states_from_tabular()] and
+#' [create_matrix_from_tabular()].
 #' 
 #' @param state_info A state tabular file (file path or 
 #'   parsed file).
@@ -671,23 +717,26 @@ create_options_from_tabular <- function(opt) {
 #'   path or parsed file).
 #' @param df_env An environment containing external data.
 #' 
-#' @return A \code{heemod} model as returned by 
-#'   \code{\link{define_strategy}}.
+#' @return A `heemod` model as returned by 
+#'   [define_strategy()].
 #'   
 #' @keywords internal
 create_model_from_tabular <- function(state_info,
                                       tm_info,
                                       df_env = globalenv()) {
-  if(length(tm_info) == 0) {
-    stop("A transition matrix must be defined.")
+  if (length(tm_info) == 0) {
+    stop("A transition object must be defined.")
   }
   
-  if(! inherits(state_info, "data.frame")) {
+  if (! inherits(state_info, "data.frame")) {
     stop("'state_info' must be a data frame.")
   }
   
-  if(!is.null(tm_info) && ! inherits(tm_info, "data.frame")) {
-    stop("'tm_info' must be a data frame.")
+  if (!is.null(tm_info) &&
+      ! inherits(tm_info, c("data.frame", "part_surv"))) {
+    stop("'tm_info' must be either a data frame ",
+         "defining a transition matrix or a part_surv object ",
+         "defining a partitioned survival model.")
   }
   
   if (options()$heemod.verbose) message("**** Defining state list...")
@@ -695,8 +744,15 @@ create_model_from_tabular <- function(state_info,
                                        df_env = df_env)
   if (options()$heemod.verbose) message("**** Defining TM...")
   
-  TM <- create_matrix_from_tabular(tm_info, get_state_names(states),
-                                   df_env = df_env)
+  if (inherits(tm_info, "data.frame")) {
+    TM <- create_matrix_from_tabular(
+      tm_info, get_state_names(states),
+      df_env = df_env)
+  }
+  
+  if (inherits(tm_info, "part_surv")) {
+    TM <- tm_info
+  }
   
   define_strategy_(transition = TM, states = states)
 }
@@ -751,31 +807,31 @@ create_df_from_tabular <- function(df_dir, df_envir) {
 
 #'Specify Inputs for Multiple Models From a Single File
 #'
-#'Parse a \code{data.frame} containing specifications for 
+#'Parse a `data.frame` containing specifications for 
 #'multiple models into a list of inputs required for each 
 #'model.
 #'
 #'Each combination of values of the columns specified by 
-#'\code{group_vars} should either be unique in the file (in 
+#'`group_vars` should either be unique in the file (in 
 #'which case it will be replicated for all values of 
-#'\code{split_on}), or must be repeated as many times as 
-#'unique values of \code{split_on}.
+#'`split_on`), or must be repeated as many times as 
+#'unique values of `split_on`.
 #'
-#'\code{split_on} is usually the model name.
+#'`split_on` is usually the model name.
 #'
-#'\code{group_var} can be the state names, or from and to 
+#'`group_var` can be the state names, or from and to 
 #'lines for a matrix definition...
 #'
-#'@param multi_spec \code{data frame}.
-#'@param split_on \code{character} of length 1, with the 
-#'  name of the variable in \code{multi_spec} to be split 
+#'@param multi_spec `data frame`.
+#'@param split_on `character` of length 1, with the 
+#'  name of the variable in `multi_spec` to be split 
 #'  on.
-#'@param group_vars \code{character}, one or more variable 
-#'  names from \code{multi_spec} that identify a line of 
+#'@param group_vars `character`, one or more variable 
+#'  names from `multi_spec` that identify a line of 
 #'  information.
 #'  
 #'@return A list of data frames, one for each value of 
-#'  \code{split_on.}
+#'  `split_on.`
 #'   
 #' @keywords internal
 parse_multi_spec <- function(multi_spec,
@@ -854,7 +910,7 @@ parse_multi_spec <- function(multi_spec,
 #' This function mostly checks whether the parameters are
 #' correct.
 #' 
-#' An optional \code{.weights} column can exist in the file.
+#' An optional `.weights` column can exist in the file.
 #' 
 #' @param newdata A data frame.
 #' @param params Parameters of a model, to check that all
@@ -892,7 +948,7 @@ create_demographic_table <- function(newdata,
 #' 
 #' @param file_name File name.
 #' 
-#' @return A \code{data.frame}.
+#' @return A `data.frame`.
 #'   
 #' @keywords internal
 read_file <- function(file_name) {
@@ -934,15 +990,15 @@ read_file <- function(file_name) {
 
 #' Remove Blank Rows From Table
 #' 
-#' Remove rows were all values are \code{NA}.
+#' Remove rows were all values are `NA`.
 #' 
 #' Some rows can be left blanks in the input table for 
 #' readability, this function ensures those rows are 
 #' removed.
 #' 
-#' @param x A \code{data.frame}.
+#' @param x A `data.frame`.
 #'   
-#' @return A \code{data.frame} without blank rows.
+#' @return A `data.frame` without blank rows.
 #'   
 #' @keywords internal
 filter_blanks <- function(x) {
@@ -974,11 +1030,11 @@ is_xls <- function(x) {
 #' Save Model Outputs
 #' 
 #' @param outputs Result from
-#'   \code{\link{run_model_tabular}}.
+#'   [run_model_tabular()].
 #' @param output_dir Subdirectory in which to write output.
 #' @param overwrite Should the outputs be overwritten?
 #'   
-#' @return \code{NULL}. Used for its side effect of creating
+#' @return `NULL`. Used for its side effect of creating
 #'   files in the output directory.
 #'   
 #' @keywords internal
@@ -1016,13 +1072,13 @@ save_outputs <- function(outputs, output_dir, overwrite) {
       row.names = FALSE
     )
   }
-
+  
   utils::write.csv(
     get_counts(outputs$model_runs),
     file = file.path(output_dir, "state_counts.csv"),
     row.names = FALSE
   )
-
+  
   utils::write.csv(
     get_values(outputs$model_runs),
     file = file.path(output_dir, "cycle_values.csv"),
@@ -1089,3 +1145,101 @@ save_graph <- function(plot, path, file_name) {
   print(plot)
   grDevices::dev.off()
 }
+
+
+transition_type <- function(tm_info) {
+  which_defines <- NULL
+  if (all(names(tm_info)[1:2] == c("data", "val"))) {
+    which_defines <- "part_surv"
+  }
+  
+  if (all(names(tm_info)[1:4] == c(".model", "from", "to", "prob"))) {
+    which_defines <- "matrix"
+  }
+  
+  if (is.null(which_defines)) {
+    stop("The data frame 'tm_info' must define ",
+         "either a transition matrix or a partitioned survival object.")
+  }
+  which_defines
+}
+
+modify_param_defs_for_multinomials <- function(param_defs, psa) {
+  param_names <- param_defs[, 1]
+  multinom_pos <- grep("\\+", param_names)
+  
+  multinom_vars <- lapply(
+    multinom_pos,
+    function(i) {
+      strsplit(param_names[[i]], "+", fixed = TRUE)[[1]]
+    })
+  
+  multinom_vars <- lapply(
+    multinom_vars,
+    function(x) {
+      gsub("[[:space:]]", "", x)
+    })
+  
+  duplicates <- sapply(
+    param_defs$parameter,
+    function(x){
+      x %in% unlist(multinom_vars)
+    })
+  
+  if (any(duplicates)) {
+    stop("Some variables appear as individual parameters ",
+         "and in a multinomial: ",
+         paste(param_defs$parameter[duplicates], collapse = ", ")
+    )
+  }
+  
+  multinom_counts <- lapply(
+    multinom_vars,
+    function(x) {
+      sapply(
+        psa$list_qdist[x],
+        function(y) {
+          eval(expression(n),
+               environment(y))
+        })
+    })
+  
+  multinom_probs <- lapply(
+    multinom_counts,
+    function(x) {
+      x / sum(x)
+    })
+  
+  replacements <- lapply(
+    multinom_probs,
+    function(x) {
+      zz <- data.frame(
+        parameter = names(x),
+        value = x)
+      rownames(zz) <- NULL
+      zz
+    })
+  
+  ## now we need to put these where they initially appeared
+  ##   in the parameter file
+  
+  param_defs <- param_defs[, c("parameter", "value")]
+  param_defs_old <- param_defs
+  for (i in rev(seq(along = multinom_pos))) {
+    this_pos <- multinom_pos[i]
+    start_index <- 1:(this_pos - 1)
+    end_index <- 
+      if (this_pos == nrow(param_defs)) {
+        numeric(0)
+    } else {
+      (this_pos + 1):nrow(param_defs)
+    }
+    
+    param_defs <- rbind(
+      param_defs[start_index,],
+      replacements[[i]],
+      param_defs[end_index,])
+  }
+  
+  param_defs
+}
