@@ -18,13 +18,14 @@ test_that(
     ##   instead, we'll check parts that use multi-core processing
     ## 
     ##  parameters from the discrete sensitivity analysis
-    expect_identical(result_1core$dsa$dsa$.par_value,
-                     result_2core$dsa$dsa$.par_value)
+    expect_identical(sapply(result_1core$dsa$dsa$.par_value, lazyeval::lazy_eval),
+                     sapply(result_2core$dsa$dsa$.par_value, lazyeval::lazy_eval)
+    )
     ##  counts from all models from the discrete sensitivity analysis
     expect_identical(get_counts(get_model(result_1core$dsa)),
                      get_counts(get_model(result_2core$dsa)))
     ## demographic analysis
-    expect_equal(result_1core$demographics$updated_model,
-                 result_2core$demographics$updated_model)
+    expect_equivalent(result_1core$demographics$updated_model[-3],
+                      result_2core$demographics$updated_model[-3])
   }
 )
